# ShariX Open Tickets

Ticketing system implemented as a Django application.

## Installation

1) Download or clone repository

```bash
git clone -b tickets_module http://git.sharix-app.org/ShariX_Open/sharix-open-tickets.git tickets
```

2) Install required dependencies in project settings

```python
INSTALLED_APPS = [
    ...
    'tickets.apps.ticketsConfig',
    'django.contrib.sites',
    ...
]
```

3) Delete the migration files in the **migrations** folder (everything except __init__.py)

4) Install required libraries (don't forget to install and activate virtual space)

```powershell
pip install -r tickets/requirements.txt
```

Start test the server:

```bash
python manage.py runserver 8000
```

If the port has not been selected, it is 8000 by default. If selected port is busy, use another one (for example, try increasing port number by 1 until the server starts). A link to the website should appear in the terminal.

## Settings

Optional configuration params, which can be added to your project settings:

```python
# Restrict access to ALL tickets lists/views to `is_staff` users.
# If False or unset, all users can see all views (but more granular permissions are still enforced
# within views, such as requiring staff for adding and deleting lists).
TICKETS_STAFF_ONLY = True

# If you use the "public" ticket filing option, to whom should these tickets be assigned?
# Must be a valid username in your system. If unset, unassigned tickets go to "Anyone."
TICKETS_DEFAULT_ASSIGNEE = 'johndoe'

# If you use the "public" ticket filing option, to which list should these tickets be saved?
# Defaults to first list found, which is probably not what you want!
TICKETS_DEFAULT_LIST_SLUG = 'tickets'

# If you use the "public" ticket filing option, to which *named URL* should the user be
# redirected after submitting? (since they can't see the rest of the ticket system).
# Defaults to "/"
TICKETS_PUBLIC_SUBMIT_REDIRECT = 'dashboard'

# Enable or disable file attachments on Tasks
# Optionally limit list of allowed filetypes
TICKETS_ALLOW_FILE_ATTACHMENTS = True
TICKETS_ALLOWED_FILE_ATTACHMENTS = [".jpg", ".gif", ".csv", ".pdf", ".zip"]
TICKETS_MAXIMUM_ATTACHMENT_SIZE = 5000000  # In bytes

# Additional classes the comment body should hold.
# Adding "text-monospace" makes comment monospace
TICKETS_COMMENT_CLASSES = []

# The following two settings are relevant only if you want TICKETS to track a support mailbox -
# see Mail Tracking below.
TICKETS_MAIL_BACKENDS
TICKETS_MAIL_TRACKERS
```
